@@ -1,4 +1,4 @@
-//$Id: add-resource.cc,v 1.19 2002/10/27 22:17:14 cactus Exp $ -*- c++ -*-
+//$Id: add-resource.cc,v 1.21 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,6 +27,8 @@
 #include "resource-manager.h"
 #include "resource-manager-ops.h"
 
+#include "mainwin.h"
+
 using namespace Guikachu;
 
 GUI::AddResourceWin::AddResourceWin (ResourceManager *manager_):
@@ -95,7 +97,18 @@ void GUI::AddResourceWin::run ()
 
     if (dialog_result == 0)
     {
-	Resource *res = manager->create_resource (res_type, entry->get_text ());
+	std::string id = entry->get_text ();
+	
+	Resource *res = manager->create_resource (res_type, id);
+	if (!res)
+	{
+	    char *error_msg = g_strdup_printf (_("Non-unique identifier `%s'"), id.c_str ());
+	    GUI::show_error (error_msg);
+	    g_free (error_msg);
+
+	    return;
+	}
+	
 	manager->get_undo_manager ().push (new ResourceOps::CreateOp (res));
     }
 }
