@@ -1,4 +1,4 @@
-//$Id: app-res.cc,v 1.19 2002/06/14 21:37:52 cactus Exp $ -*- c++ -*-
+//$Id: app-res.cc,v 1.20 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,8 +44,8 @@ void Resources::Application::VendorID::set_val (const string& value_)
     }
 }
 
-Resources::Application::Application (ResourceManager *owner_):
-    owner (owner_),
+Resources::Application::Application (ResourceManager *manager_):
+    manager (manager_),
     gui (0),
     iconname (changed, ""),
     version (changed, ""),
