@@ -1,4 +1,4 @@
-//$Id: blob-res.h,v 1.10 2002/08/01 18:06:01 cactus Exp $ -*- c++ -*-
+//$Id: blob-res.h,v 1.11 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,7 +42,7 @@ namespace Guikachu
 	{
 	    GUI::BlobWindow *gui;
 	public:
-	    Blob (ResourceManager *owner, const std::string &id);
+	    Blob (ResourceManager *manager, const std::string &id);
 	    ~Blob ();
 
 	    Type get_type () const { return RESOURCE_BLOB; };
