@@ -1,4 +1,4 @@
-//$Id: dialog-res.h,v 1.17 2002/08/01 18:06:01 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.h,v 1.18 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -53,7 +53,7 @@ namespace Guikachu
 		TYPE_ERROR
 	    };
 	    
-	    Dialog (ResourceManager *owner, const std::string &id);
+	    Dialog (ResourceManager *manager, const std::string &id);
 	    ~Dialog ();
 	    
 	    Type get_type () const { return RESOURCE_DIALOG; };
