@@ -1,4 +1,4 @@
-//$Id: auto-resizeable.h,v 1.3 2002/03/15 17:47:08 cactus Exp $ -*- c++ -*-
+//$Id: auto-resizeable.h,v 1.5 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,18 +27,18 @@ namespace Guikachu
     {
 	class AutoWidth: public virtual ResizeableWidget
 	{
-	    SigC::Signal0<void> &changed_propagate;
-	    SigC::Signal0<void>  manual_width_changed;
+	    VSignal &changed_propagate;
+	    VSignal  manual_width_changed;
 
 	protected:
-	    AutoWidth (SigC::Signal0<void> &changed);
+	    AutoWidth (VSignal &changed);
 
 	    virtual int get_auto_width () const = 0;
 
 	public:
 	    virtual ~AutoWidth () {};
 
-	    int get_display_width ()  const;
+	    int get_width ()  const;
 
 	    Property<bool> manual_width;
 
@@ -50,18 +50,18 @@ namespace Guikachu
 	
 	class AutoHeight: public virtual ResizeableWidget
 	{
-	    SigC::Signal0<void> &changed_propagate;
-	    SigC::Signal0<void>  manual_height_changed;
+	    VSignal &changed_propagate;
+	    VSignal  manual_height_changed;
 
 	protected:
-	    AutoHeight (SigC::Signal0<void> &changed);
+	    AutoHeight (VSignal &changed);
 
 	    virtual int get_auto_height () const = 0;
 
 	public:
 	    virtual ~AutoHeight () {};
 
-	    int get_display_height () const;
+	    int get_height () const;
 
 	    Property<bool> manual_height;
 
