@@ -1,4 +1,4 @@
-//$Id: button-canvas.cc,v 1.21 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.cc,v 1.23 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,8 +19,7 @@
 #include "button-canvas.h"
 
 #include "form-editor.h"
-
-#include <gnome--/canvas-polygon.h>
+#include "resizeable-ops.h"
 
 using namespace Guikachu::GUI::FormEditor;
 
@@ -28,7 +27,7 @@ ButtonCanvasItem::ButtonCanvasItem (Widgets::Button    *widget_,
 				    Gnome::CanvasGroup *parent_group):
     CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
-    ResizeableCanvasItem (widget_, parent_group),
+    ResizeableCanvasItem (widget_, parent_group, new WidgetOps::ResizeOpFactory (widget_)),
     widget (widget_),
     group (0)
 {
