@@ -1,4 +1,4 @@
-//$Id: checkbox-canvas.cc,v 1.24 2002/06/23 15:45:30 cactus Exp $ -*- c++ -*-
+//$Id: checkbox-canvas.cc,v 1.26 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,7 @@
 #include "checkbox-canvas.h"
 
 #include "form-editor.h"
+#include "resizeable-ops.h"
 
 using namespace Guikachu::GUI::FormEditor;
 
@@ -26,7 +27,7 @@ CheckboxCanvasItem::CheckboxCanvasItem (Widgets::Checkbox  *widget_,
 					Gnome::CanvasGroup *parent_group):
     CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
-    ResizeableCanvasItem (widget_, parent_group),
+    ResizeableCanvasItem (widget_, parent_group, new WidgetOps::ResizeOpFactory (widget_)),
     widget (widget_),
     group (0)
 {
