@@ -1,4 +1,4 @@
-//$Id: checkbox-prop.cc,v 1.12 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
+//$Id: checkbox-prop.cc,v 1.16 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,14 +32,16 @@
 #include "widgets/togglebutton.h"
 #include "widgets/propertytable.h"
 
+#include "property-ops-widget.h"
+
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
 CheckboxProperties::CheckboxProperties (Checkbox *res)
 {
-    using namespace Gtk;
     using namespace SigC;
-
+    using WidgetOps::PropChangeOpFactory;
+    
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
     Gtk::Widget *control;
     
@@ -50,22 +52,31 @@ CheckboxProperties::CheckboxProperties (Checkbox *res)
     TextualProperties::add_controls (res, *proptable);
 
     /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (res->usable);
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->usable,
+	new PropChangeOpFactory<bool> (
+	    _("Toggle usable state of %s"), res, res->usable, false));
     proptable->add (_("_Usable:"), *manage (control),
 		    _("Non-usable widgets are not rendered by default"));
 
     /* Group ID */
-    control = new GUI::PropertyEditors::NumEntry(0, 65535, res->group);
+    control = new GUI::PropertyEditors::NumEntry(
+	0, 65535, res->group,
+	new PropChangeOpFactory<int> (_("Change group ID of %s"), res, res->group, true));
     proptable->add (_("_Group ID:"), *manage (control),
 		    _("Only one checkbox can be selected "
 		      "per group (select 0 for non-exclusive "
 		      "check boxes)"));
     /* Toggled */
-    control = new GUI::PropertyEditors::ToggleButton (res->toggled);
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->toggled,
+	new PropChangeOpFactory<bool> (_("Toggle %s"), res, res->toggled, false));	
     proptable->add (_("_Toggled:"), *manage (control));
     
-    /* Toggled */
-    control = new GUI::PropertyEditors::ToggleButton (res->anchor_right);
+    /* Alignment */
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->anchor_right,
+	new PropChangeOpFactory<bool> (_("Change alignment of %s"), res, res->anchor_right, false));
     proptable->add (_("_Anchor right:"), *manage (control),
 		    _("Keep right aligned when changing label "
 		      "text at run-time"));
