@@ -1,4 +1,4 @@
-//$Id: font.h,v 1.9 2002/05/30 19:00:38 cactus Exp $ -*- c++ -*-
+//$Id: font.h,v 1.10 2002/08/06 23:48:35 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -76,11 +76,13 @@ namespace Guikachu
 
 	    private:
 		const Glyph& get_glyph (char c) const;
+
+		typedef std::list<const Glyph*> typeset_t;
 		
-		void render_raw_line (const std::list<Glyph> &typeset,
-				      const Gdk_Color        &color,
-				      guint8                 *target,
-				      int                     target_rowstride) const;
+		void render_raw_line (const typeset_t &typeset,
+				      const Gdk_Color &color,
+				      guint8          *target,
+				      int              target_rowstride) const;
 
 		int get_raw_line_width (const std::string &text) const;
 	    };
