@@ -1,4 +1,4 @@
-//$Id: form-canvas.cc,v 1.10 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
+//$Id: form-canvas.cc,v 1.11 2003/01/26 17:35:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,8 +27,6 @@
 #include <gtk--/main.h>
 #include <gdk-pixbuf/gnome-canvas-pixbuf.h>
 #include <sigc++/retbind.h>
-#include <gnome--/app-helper.h>
-#include <libgnomeui/gnome-stock.h>
 
 #include <list>
 #include <math.h>
@@ -46,25 +44,13 @@ FormCanvasItem::FormCanvasItem (Widgets::Form      *form_widget,
     ResizeableCanvasItem (form_widget, parent_group,
 			  new ResourceOps::FormResizeOpFactory (form_widget)),
     res (form_widget->get_resource ()),
-    group (0),
     background_item (0),
     frame_group (0),
     title_group (0),
-    widget_group (0)
+    widget_group (new Gnome::CanvasGroup (*item_group, 0, 0))
 {
     using namespace SigC;
 
-    //group = new Gnome::CanvasGroup (*draw_group, 0, 0);
-    group = item_group;
-    widget_group = new Gnome::CanvasGroup (*item_group, 0, 0);
-
-    // Popup menu
-    std::list <Gnome::UI::Info> popup_menu_list;
-    popup_menu_list.push_back (
-	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_PROP),
-			 _("_Edit"), clicked.slot ()));
-    Gnome::UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
-
     res->changed.connect (slot (this, &FormCanvasItem::update));
     update ();
 }
@@ -75,16 +61,17 @@ void FormCanvasItem::update ()
     draw_frame ();
     draw_title ();
 
-    group->set_x (0);
-    group->set_y (0);
-    group->move (res->x, res->y);
+    item_group->set_x (0);
+    item_group->set_y (0);
+    item_group->move (res->x, res->y);
 
     widget_group->raise_to_top ();
+    overlay_group->raise_to_top ();
 }
 
 void FormCanvasItem::move (int dx, int dy)
 {
-    group->move (dx, dy);
+    item_group->move (dx, dy);
 }
 
 Gnome::CanvasGroup *FormCanvasItem::get_widget_group ()
@@ -107,6 +94,8 @@ void FormCanvasItem::draw_background ()
     *background_item
 	<< width_pixels (0)
 	<< fill_color (get_background_color ());
+    background_item->event.connect (
+	SigC::retbind (SigC::slot (this, &FormCanvasItem::canvas_event_cb), 1));
     background_item->lower_to_bottom ();
 }
 
@@ -114,13 +103,15 @@ void FormCanvasItem::draw_frame ()
 {
     delete frame_group;
     frame_group = new Gnome::CanvasGroup (*draw_group, 0, 0);
-    
+
+#if 0
     Gnome::CanvasRect *frame_rect =
 	new Gnome::CanvasRect (*frame_group,
 			       -1, -1,
 			       res->width, res->height);
     frame_rect->set_width_units (1);
     frame_rect->set_fill_color ("");
+#endif
     
     if (res->modal)
 	draw_frame_modal ();
@@ -301,7 +292,7 @@ void FormCanvasItem::canvas_event_cb (GdkEvent *e)
     // Context menu
     if ((e->type == GDK_BUTTON_PRESS) &&
 	(e->button.button == 3))
-	popup_menu.popup (e->button.button, e->button.time);
+	context_menu.emit (e->button.button, e->button.time);
 }
 
 void FormCanvasItem::get_bounds (int &x1, int &y1,
