@@ -1,4 +1,4 @@
-//$Id: form-element.h,v 1.5 2002/02/16 17:15:12 cactus Exp $ -*- c++ -*-
+//$Id: form-element.h,v 1.7 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,7 +19,7 @@
 #ifndef GUIKACHU_FORM_EDITOR_FORM_ELEMENT_H
 #define GUIKACHU_FORM_EDITOR_FORM_ELEMENT_H
 
-//#include "form-editor/canvasitem.h"
+#include "resource-manager.h"
 
 namespace Guikachu
 {
@@ -36,6 +36,12 @@ namespace Guikachu
 	virtual int get_y () const = 0;
 	virtual void set_x (int x) = 0;
 	virtual void set_y (int y) = 0;
+
+	// Geometry
+	virtual int get_width  () const = 0;
+	virtual int get_height () const = 0;
+
+	virtual ResourceManager *get_manager () const = 0;
 	
 	SigC::Signal1<void, bool> selected;
 	SigC::Signal1<void, bool> selected_last;
