@@ -1,4 +1,4 @@
-//$Id: graffiti.h,v 1.12 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
+//$Id: graffiti.h,v 1.13 2002/08/01 18:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,11 +40,11 @@ namespace Guikachu
 	    GUI::FormEditor::GraffitiProperties *editor;
 	    
 	public:
-	    Graffiti (Resources::Form   *owner,
-		      const std::string &id);
+	    Graffiti (Resources::Form *owner, const std::string &id);
 	    ~Graffiti ();
 	    
 	    Type get_type () const { return WIDGET_GRAFFITI; };
+	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
 
 	    // Implementation of FormElement methods
 	    int get_width  () const;
