@@ -1,4 +1,4 @@
-//$Id: label-canvas.cc,v 1.11 2002/01/29 22:55:05 cactus Exp $ -*- c++ -*-
+//$Id: label-canvas.cc,v 1.13 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,10 +41,17 @@ void LabelCanvasItem::update ()
     
     group = new Gnome::CanvasGroup (*draw_group, 0, 0);
 
+    // Avoid 0x0 rendering, as that would make it impossible to select
+    // the widget
+    std::string text = widget->text;
+    if (text == "")
+	text = " ";
+    
     draw_text (*group,
-	       widget->text, widget->font,
+	       text, widget->font,
 	       widget->x, widget->y,
-	       widget->usable);
+	       widget->usable,
+	       true /* Labels can have multiple lines of text */);
 
     set_canvas_item (group);
 }
