@@ -1,4 +1,4 @@
-//$Id: popup-trigger-prop.cc,v 1.10 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger-prop.cc,v 1.13 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,6 +25,8 @@
 #include "auto-resizeable-prop.h"
 #include "textual-prop.h"
 
+#include "property-ops-widget.h"
+
 #include "widgets/entry.h"
 #include "widgets/num-entry.h"
 #include "widgets/togglebutton.h"
@@ -36,9 +38,9 @@ using namespace Guikachu::Widgets;
 
 PopupTriggerProperties::PopupTriggerProperties (PopupTrigger *res)
 {
-    using namespace Gtk;
     using namespace SigC;
-
+    using WidgetOps::PropChangeOpFactory;
+    
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
     Gtk::Widget *control;
     
@@ -48,18 +50,24 @@ PopupTriggerProperties::PopupTriggerProperties (PopupTrigger *res)
     /* Label */
     TextualProperties::add_controls (res, *proptable);
 
-    /* Default button */
-    control = new GUI::PropertyEditors::WidgetCombo (res->get_form (), Widgets::WIDGET_LIST, res->list_id);
+    /* List to pop up */
+    control = new GUI::PropertyEditors::WidgetCombo (
+	res->get_form (), Widgets::WIDGET_LIST, res->list_id,
+	new PropChangeOpFactory<std::string> (_("Change popup list of %s"), res, res->list_id));
     proptable->add (_("_List ID:"), *manage (control),
-		    _("List to pup up upon activation"));
+		    _("List to pop up upon activation"));
     
     /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (res->usable);
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->usable,
+	new PropChangeOpFactory<bool> (_("Toggle usable state of %s"), res, res->usable, false));
     proptable->add (_("_Usable:"), *manage (control),
 		    _("Non-usable widgets are not rendered by default"));
 
     /* Anchor right */
-    control = new GUI::PropertyEditors::ToggleButton (res->anchor_right);
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->anchor_right,
+	new PropChangeOpFactory<bool> (_("Change alignment of %s"), res, res->anchor_right, false));
     proptable->add (_("_Anchor right:"), *manage (control),
 		    _("Keep right aligned when changing label "
 		      "text at run-time"));
