@@ -1,4 +1,4 @@
-//$Id: resizeable-widget.cc,v 1.2 2002/03/17 17:53:49 cactus Exp $ -*- c++ -*-
+//$Id: resizeable-widget.cc,v 1.3 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,7 +22,7 @@
 
 using namespace Guikachu::Widgets;
 
-ResizeableWidget::ResizeableWidget (SigC::Signal0<void> &changed):
+ResizeableWidget::ResizeableWidget (VSignal &changed):
     Resizeable (_width, _height),
     real_changed (changed),
     _width (width_changed, 0),
