@@ -1,4 +1,4 @@
-//$Id: resizeable-widget.h,v 1.2 2002/03/17 17:53:49 cactus Exp $ -*- c++ -*-
+//$Id: resizeable-widget.h,v 1.3 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,15 +31,15 @@ namespace Guikachu
 	class ResizeableWidget: public Resizeable,
 				public SigC::Object
 	{
-	    SigC::Signal0<void> &real_changed;
-	    SigC::Signal0<void>  width_changed;
-	    SigC::Signal0<void>  height_changed;
+	    VSignal &real_changed;
+	    VSignal  width_changed;
+	    VSignal  height_changed;
 	    
 	    Property<int> _width;
 	    Property<int> _height;
 
 	protected:
-	    ResizeableWidget (SigC::Signal0<void> &changed);
+	    ResizeableWidget (VSignal &changed);
 	    
 	private:
 	    void emit_changed ();
