@@ -1,4 +1,4 @@
-//$Id: scrollbar-prop.cc,v 1.11 2002/06/02 13:53:41 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-prop.cc,v 1.14 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,15 +29,17 @@
 #include "widgets/size-entry.h"
 #include "widgets/auto-toggle.h"
 
+#include "property-ops-widget.h"
+
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
 ScrollBarProperties::ScrollBarProperties (ScrollBar *res_):
     res (res_)
 {
-    using namespace Gtk;
     using namespace SigC;
-
+    using WidgetOps::PropChangeOpFactory;
+    
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
     Gtk::Widget *control;
     
@@ -45,27 +47,37 @@ ScrollBarProperties::ScrollBarProperties (ScrollBar *res_):
     WidgetProperties::add_general_controls (res, *proptable);
 
     /* Current value */
-    control = value = new GUI::PropertyEditors::NumEntry (0, 32767, res->value);
+    control = value = new GUI::PropertyEditors::NumEntry (
+	0, 32767, res->value,
+	new PropChangeOpFactory<int> (_("Change value of %s"), res, res->value, true));
     proptable->add (_("_Value:"), *manage (control),
 		    _("Default value of scrollbar"));
 
     /* Max and min value */
-    control = min_value = new GUI::PropertyEditors::NumEntry (0, 32767, res->min_value);
+    control = min_value = new GUI::PropertyEditors::NumEntry (
+	0, 32767, res->min_value,
+	new PropChangeOpFactory<int> (_("Change minimum value of %s"), res, res->min_value, true));
     proptable->add (_("Mi_nimum:"), *manage (control),
 		    _("Minimum value allowed"));
 
-    control = max_value = new GUI::PropertyEditors::NumEntry (0, 32767, res->max_value);
+    control = max_value = new GUI::PropertyEditors::NumEntry (
+	0, 32767, res->max_value,
+	new PropChangeOpFactory<int> (_("Change maximum value of %s"), res, res->max_value, true));
     proptable->add (_("Ma_ximum:"), *manage (control),
 		    _("Maximum value allowed"));    
 
     /* Page size */
-    control = new GUI::PropertyEditors::NumEntry (0, 32767, res->page_size);
+    control = new GUI::PropertyEditors::NumEntry (
+	0, 32767, res->page_size,
+	new PropChangeOpFactory<int> (_("Change page size of %s"), res, res->page_size, true));
     proptable->add (_("_Page size:"), *manage (control),
 		    _("The amount of slider movement when the "
 		      "scrollbar itself is clicked by the user"));
     
     /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (res->usable);
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->usable,
+	new PropChangeOpFactory<bool> (_("Toggle usable state of %s"), res, res->usable, false));
     proptable->add (_("_Usable:"), *manage (control),
 		    _("Non-usable widgets are not rendered by default"));
 
@@ -77,14 +89,21 @@ ScrollBarProperties::ScrollBarProperties (ScrollBar *res_):
     
     /* Size */
     /* Width */
-    control = new GUI::PropertyEditors::WidthEntry (res->get_manager (), res->width);
-    control = new GUI::PropertyEditors::AutoToggle (*manage (control), res->manual_width);
+    control = new GUI::PropertyEditors::WidthEntry (
+	res->get_manager (), res->width,
+	new PropChangeOpFactory<int> (_("Resize %s"), res, res->width, true));
+    control = new GUI::PropertyEditors::AutoToggle (
+	*manage (control), res->manual_width,
+	new PropChangeOpFactory<bool> (
+	    _("Change manual resizing of %s"), dynamic_cast<Widget*> (res), res->manual_width));
     proptable->add (_("_Width:"), *manage (control),
 		    _("Horizontal size of the widget "
 		      "(check to set manually)"));
 
     /* Height */
-    control = new GUI::PropertyEditors::HeightEntry (res->get_manager (), res->height);
+    control = new GUI::PropertyEditors::HeightEntry (
+	res->get_manager (), res->height,
+	new PropChangeOpFactory<int> (_("Resize %s"), res, res->height, true));
     proptable->add (_("_Height:"), *manage (control),
 		    _("Vertical size of the widget"));
     
