@@ -1,4 +1,4 @@
-//$Id: selector-trigger-prop.cc,v 1.9 2002/01/26 00:19:17 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-prop.cc,v 1.11 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,14 +30,16 @@
 #include "widgets/togglebutton.h"
 #include "widgets/propertytable.h"
 
+#include "property-ops-widget.h"
+
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
 SelectorTriggerProperties::SelectorTriggerProperties (SelectorTrigger *res)
 {
-    using namespace Gtk;
     using namespace SigC;
-
+    using WidgetOps::PropChangeOpFactory;
+    
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
     Gtk::Widget *control;
     
@@ -48,12 +50,16 @@ SelectorTriggerProperties::SelectorTriggerProperties (SelectorTrigger *res)
     TextualProperties::add_controls (res, *proptable);
 
     /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (res->usable);
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->usable,
+	new PropChangeOpFactory<bool> (_("Toggle usable state of %s"), res, res->usable, false));
     proptable->add (_("_Usable:"), *manage (control),
 		    _("Non-usable widgets are not rendered by default"));
 
     /* Anchor right */
-    control = new GUI::PropertyEditors::ToggleButton (res->anchor_right);
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->anchor_right,
+	new PropChangeOpFactory<bool> (_("Change alignment of %s"), res, res->anchor_right, false));
     proptable->add (_("A_nchor right:"), *manage (control),
 		    _("Keep right aligned when changing label "
 		      "text at run-time"));
