@@ -1,4 +1,4 @@
-//$Id: selector-trigger.h,v 1.16 2002/06/14 21:37:54 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.h,v 1.17 2002/08/01 18:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -45,14 +45,14 @@ namespace Guikachu
 	    GUI::FormEditor::SelectorTriggerProperties *editor;
 	    
 	public:
-	    SelectorTrigger (Resources::Form   *owner,
-			     const std::string &id);
-	    virtual ~SelectorTrigger ();
+	    SelectorTrigger (Resources::Form *owner, const std::string &id);
+	    ~SelectorTrigger ();
 	    
-	    virtual Type get_type () const { return WIDGET_SELECTOR_TRIGGER; };
+	    Type get_type () const { return WIDGET_SELECTOR_TRIGGER; };
+	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
 	    
-	    virtual Gtk::Widget                       *create_editor ();
-	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
+	    Gtk::Widget                       *create_editor ();
+	    GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
 
 	    Property<bool>   usable;
 	    Property<bool>   anchor_right;
