@@ -1,4 +1,4 @@
-//$Id: text-field.h,v 1.13 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
+//$Id: text-field.h,v 1.14 2002/08/01 18:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,14 +42,14 @@ namespace Guikachu
 	    GUI::FormEditor::TextFieldProperties *editor;
 	    
 	public:
-	    TextField (Resources::Form   *owner,
-		       const std::string &id);
-	    virtual ~TextField ();
+	    TextField (Resources::Form *owner, const std::string &id);
+	    ~TextField ();
 	    
-	    virtual Type get_type () const { return WIDGET_TEXT_FIELD; };
+	    Type get_type () const { return WIDGET_TEXT_FIELD; };
+	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
 	    
-	    virtual Gtk::Widget                       *create_editor ();
-	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
+	    Gtk::Widget                       *create_editor ();
+	    GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
 
 	    Property<bool> usable;
 
