@@ -1,4 +1,4 @@
-//$Id: textual-prop.cc,v 1.6 2002/01/05 23:35:20 cactus Exp $ -*- c++ -*-
+//$Id: textual-prop.cc,v 1.9 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,8 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+#include "property-ops-widget.h"
+
 #include "widgets/entry.h"
 #include "widgets/font-combo.h"
 
@@ -32,10 +34,14 @@ void TextualProperties::add_controls (Widgets::Textual   *res,
     Gtk::Widget *control;
     
     /* Label */
-    control = new GUI::PropertyEditors::Entry (true, res->text);
+    control = new GUI::PropertyEditors::Entry (
+	true, res->text, new WidgetOps::PropChangeOpFactory<std::string> (
+	    _("Change label of %s"), dynamic_cast<Widget*>(res), res->text, true));
     proptable.add (_("_Text:"), *manage (control));
 
     /* Font */
-    control = new GUI::PropertyEditors::FontCombo (res->font);
+    control = new GUI::PropertyEditors::FontCombo (
+	res->font, new WidgetOps::PropChangeOpFactory<int> (
+	    _("Change font of %s"), dynamic_cast<Widget*>(res), res->font, false));
     proptable.add (_("_Font:"), *manage (control));
 }
