@@ -1,4 +1,4 @@
-//$Id: widget-canvas.h,v 1.6 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
+//$Id: widget-canvas.h,v 1.7 2003/01/22 01:31:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,7 +31,6 @@ namespace Guikachu
 }
 
 #include <sigc++/basic_signal.h>
-#include <gtk--/menu.h>
 
 #include "canvasitem.h"
 #include "widget.h"
@@ -45,8 +44,6 @@ namespace Guikachu
 	    class WidgetCanvasItem: public virtual CanvasItem
 	    {
 		Widget             *widget;
-
-		Gtk::Menu           popup_menu;
 		
 	    protected:
 		WidgetCanvasItem (Widget             *widget,
@@ -61,8 +58,7 @@ namespace Guikachu
 		virtual Gnome::CanvasItem * create_selection_box ();
 
 	    public:
-		SigC::Signal0<void> menu_edit;
-		SigC::Signal0<void> menu_remove;
+		SigC::Signal2<void, guint, guint32> context_menu;
 		
 	    private:
 		void canvas_item_changed_cb ();
