@@ -1,4 +1,4 @@
-//$Id: form-res.h,v 1.27 2002/08/01 18:06:01 cactus Exp $ -*- c++ -*-
+//$Id: form-res.h,v 1.29 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,7 +50,7 @@ namespace Guikachu
 	    std::set<Widget*> widgets;
 
 	public:
-	    Form (ResourceManager *owner, const std::string &name);
+	    Form (ResourceManager *manager, const std::string &name);
 	    ~Form ();
 	    
 	    Type get_type () const { return RESOURCE_FORM; };
@@ -58,11 +58,12 @@ namespace Guikachu
 	    void show_ui ();
 
 	    // Widget managment
-	    const std::set<Widget*>& get_widgets () const { return widgets; };
-	    Widget*                  get_widget  (const std::string& id) const;
+	    const std::set<Widget*> & get_widgets () const { return widgets; };
+	    Widget*                   get_widget  (const std::string &id) const;
 	    
 	    Widget* create_widget (Widgets::Type  type,
-				   std::string    id = "");
+				   std::string    id = "",
+				   bool           try_alternate_names = false);
 	    void    remove_widget (Widget        *widget);
 
 	    SigC::Signal1<void, Widget*> widget_created;
