@@ -1,4 +1,4 @@
-//$Id: form-win-helpers.h,v 1.8 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: form-win-helpers.h,v 1.12 2002/10/27 22:17:14 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,6 +28,8 @@
 #include <gnome--/canvas.h>
 #include <gnome--/canvas-rect.h>
 
+#include "form-editor/widget-ops.h"
+
 namespace Guikachu
 {
     namespace GUI
@@ -56,6 +58,7 @@ namespace Guikachu
 		void selection_drag  (GdkEventMotion *e);
 		void selection_end   (GdkEventButton *e);
 	    };
+
 	    
 	    class WidgetTreeItem: public Gtk::TreeItem
 	    {
@@ -74,6 +77,7 @@ namespace Guikachu
 		int button_press_cb (GdkEventButton *e);
 		void widget_selected_cb (bool selected);
 	    };
+
 	    
 	    class TopTreeItem: public Gtk::TreeItem
 	    {
@@ -89,6 +93,29 @@ namespace Guikachu
 		void update ();
 		int button_press_cb (GdkEventButton *e);
 	    };
+	    
+	    
+	    
+    
+	    
+	    class FormMoveOp: public UndoOp
+	    {
+		std::string label;
+
+		ResourceManager *manager;
+		std::string form_id;
+
+		int old_x, old_y;
+		int new_x, new_y;
+
+	    public:
+		FormMoveOp (Resources::Form *form, int new_x, int new_y);
+		virtual ~FormMoveOp () {};
+
+		void undo ();
+		void redo ();
+		std::string get_label () const { return label; };
+	    };
 	}
     }
 }
