@@ -1,4 +1,4 @@
-//$Id: form-win.h,v 1.33 2002/10/27 10:59:27 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.36 2003/01/28 19:09:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,6 +34,7 @@ namespace Guikachu
 
 #include <gtk--/window.h>
 #include <gtk--/tree.h>
+#include <gtk--/menu.h>
 #include <gtk--/spinbutton.h>
 #include <gnome--/canvas.h>
 #include <set>
@@ -66,9 +67,14 @@ namespace Guikachu
 
 	    FormWindow_Helpers::CanvasSelectionWrapper *selection_canvas;
 
-	    Widget            *edited_widget;
-	    Widget            *last_widget;
-	    std::set<Widget*>  selected_widgets;
+	    Widget    *edited_widget;
+	    Widget    *last_widget;
+	    Gtk::Menu *form_popup_menu;
+	    Gtk::Menu *widget_popup_menu;
+
+	    typedef std::set<Widget*> selection_t;
+	    selection_t               selection;
+	    
 	    SigC::Connection   edited_widget_changed_conn;
 	    
 	    Gnome::CanvasItem *canvas_overlay;
@@ -105,8 +111,15 @@ namespace Guikachu
 	    void widget_created_cb (Widget *widget);
 	    void widget_removed_cb (Widget *widget);
 
-	    void widget_menu_remove_cb (Widget *widget);
+	    void widget_remove_cb (Widget *widget);
 
+	    // Layouting
+	    void align_left   ();
+	    void align_right  ();
+	    void align_top    ();
+	    void align_bottom ();
+	    
+	    // Selection managment
 	    void selection_add    (Widget *widget);
 	    void selection_remove (Widget *widget);
 	    void selection_toggle (Widget *widget);
@@ -115,18 +128,28 @@ namespace Guikachu
 	    void remove_selection ();
 	    
 	    void select_form   ();
+	    void select_all    ();
 	    void select_widget (Widget *widget);
 
 	    void form_clicked_cb  ();
 	    void form_released_cb ();
+	    void form_menu_cb     (guint   button,
+				   guint32 time);
 
 	    void widget_selected_last_cb (bool selected, Widget *widget);
-	    void widget_clicked_cb       (Widget *widget);
-	    void widget_released_cb      (Widget *widget);
+	    void widget_clicked_cb       (Widget  *widget);
+	    void widget_released_cb      (Widget  *widget);
+	    void widget_menu_cb          (guint    button,
+					  guint32  time,
+					  Widget  *widget);
+	    void widget_cut_cb           (Widget  *widget);
+	    void widget_copy_cb          (Widget  *widget);
+	    void widget_paste_cb         ();
 	    
 	    void selection_box_cb (int x1, int y1,
 				   int x2, int y2);
-	    
+
+	    // Resizing by drag & drop
 	    void form_drag_motion_cb   (int dx, int dy);
 	    void form_drag_end_cb      (int dx, int dy);
 	    
