@@ -1,4 +1,4 @@
-//$Id: xml-loader.cc,v 1.4 2002/08/15 23:10:03 cactus Exp $ -*- c++ -*-
+//$Id: xml-loader.cc,v 1.5 2003/01/25 00:33:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -175,7 +175,11 @@ static void load_resource (ResourceManager *manager, StorageNode &node)
         return;
     }
 
-    Resource *res = manager->create_resource (Resources::type_from_type_id (node.name ()), id);
+    Resources::Type type = Resources::type_from_type_id (node.name ());
+    
+    // try_alternate_names is TRUE to make cut & paste implementable
+    // through the IO system
+    Resource *res = manager->create_resource (type, id, true);
 
     ResourceLoader loader (node);
     res->apply_visitor (loader);
