@@ -1,4 +1,4 @@
-//$Id: mainwin.cc,v 1.42 2002/10/26 23:30:32 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.44 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,8 +32,6 @@
 
 #include "resource-manager.h"
 
-#include "treeitem.h"
-#include "top-treeitem.h"
 #include "add-resource.h"
 #include "preferences-win.h"
 #include "preferences.h"
@@ -90,6 +88,10 @@ GUI::MainWin::MainWin ():
 			 "Undo placeholder"),
 	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_REDO),
 			 "Redo placeholder"),
+	Gnome::UI::Separator     (),
+	Gnome::MenuItems::Cut    (SigC::slot (this, &MainWin::cut_cb)),
+	Gnome::MenuItems::Copy   (SigC::slot (this, &MainWin::copy_cb)),
+	Gnome::MenuItems::Paste  (SigC::slot (this, &MainWin::paste_cb)),
     };
     
     /* Settings menu */
@@ -137,7 +139,6 @@ GUI::MainWin::MainWin ():
 			 _("Save project"))
     };
     create_toolbar (toolbar);
-
     
     // Listen for changes in recent file list
     Preferences::Interface::recent_files_changed.connect (
