@@ -1,4 +1,4 @@
-//$Id: mainwin.h,v 1.18 2002/08/22 15:17:13 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.h,v 1.20 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -75,6 +75,11 @@ namespace Guikachu
 	    void save_cb ();
 	    void save_as_cb ();
 	    void export_cb ();
+
+	    void cut_cb ();
+	    void copy_cb ();
+	    void paste_cb ();
+	    
 	    void preferences_cb ();
 
 	    void open (std::string filename);
