@@ -1,4 +1,4 @@
-//$Id: preferences.cc,v 1.9 2002/05/28 20:15:28 cactus Exp $ -*- c++ -*-
+//$Id: preferences.cc,v 1.10 2002/10/26 23:30:32 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -52,7 +52,7 @@ namespace Guikachu
 
 using namespace Guikachu;
 
-void Preferences::load ()
+void Preferences::init ()
 {
     // Set up GConf client
     gconf_client = gconf_client_get_default ();
@@ -71,7 +71,7 @@ void Preferences::load ()
 			     0, 0, 0);
 }
 
-void Preferences::save ()
+void Preferences::shutdown ()
 {
     gtk_object_unref (GTK_OBJECT (gconf_client));
 }
@@ -158,6 +158,11 @@ void Preferences::Interface::add_recent_file (const std::string &filename)
     g_slist_free (c_recent_list);
 }
 
+int Preferences::Interface::get_undo_size ()
+{
+    return gconf_client_get_int (gconf_client, GCONF_ROOT "/Interface/undo_size", 0);
+}
+
 
 
 SigC::Signal0<void> Preferences::FormEditor::colors_changed;
