@@ -1,4 +1,4 @@
-//$Id: property.h,v 1.15 2002/06/22 13:03:40 cactus Exp $ -*- c++ -*-
+//$Id: property.h,v 1.16 2003/01/29 20:29:58 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 
 #include "vsignal.h"
 #include <string>
+#include <vector>
 #include <iostream>
 
 namespace Guikachu
@@ -90,12 +91,18 @@ namespace Guikachu
 
     
     // String specializations
+    std::string make_7bit_string (const std::string &str);
+    std::string escape_backslashes (const std::string &src);
+    
     template<>
     std::ostream & operator<< (std::ostream &ostr, const Property<std::string> &prop);
     
     template<>
     void Property<std::string>::set_val (const std::string &value);
 
+    template<>
+    void Property<std::vector<std::string> >::set_val (const std::vector<std::string> &value);
+
     // Special property subclasses
     
     class ResourceManager; // Forward declaration
