@@ -1,4 +1,4 @@
-//$Id: resource-manager-ops.h,v 1.2 2002/08/27 20:13:11 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager-ops.h,v 1.3 2002/10/27 22:17:14 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,46 +23,50 @@
 #include "storage-node.h"
 
 namespace Guikachu
-{    
-    class ResourceRemoveOp: public UndoOp
+{
+    namespace ResourceOps
     {
-	Resource         *resource;
-	ResourceManager  *manager;
+	class RemoveOp: public UndoOp
+	{
+	    Resource         *resource;
+	    ResourceManager  *manager;
 	
-	Resources::Type   type;
-	std::string       id;
-	StorageNode       node;
+	    Resources::Type   type;
+	    std::string       id;
+	    StorageNode       node;
 	
-	std::string      label;
+	    std::string      label;
 	
-    public:
-	ResourceRemoveOp (Resource *resource);
-	virtual ~ResourceRemoveOp ();
+	public:
+	    RemoveOp (Resource *resource);
+	    virtual ~RemoveOp () {};
 	
-	std::string get_label () const;
+	    std::string get_label () const;
 	
-	void undo ();
-	void redo ();
-    };
+	    void undo ();
+	    void redo ();
+	};
 
-    class ResourceCreateOp: public UndoOp
-    {
-	ResourceManager *manager;
+	class CreateOp: public UndoOp
+	{
+	    ResourceManager *manager;
 
-	Resources::Type  type;
-	std::string      id;
+	    Resources::Type  type;
+	    std::string      id;
 
-	std::string      label;
+	    std::string      label;
 	
-    public:
-	ResourceCreateOp (Resource *resource);
-	virtual ~ResourceCreateOp ();
+	public:
+	    CreateOp (Resource *resource);
+	    virtual ~CreateOp () {};
 	
-	std::string get_label () const;
+	    std::string get_label () const;
 	
-	void undo ();
-	void redo ();	
-    };
-}
+	    void undo ();
+	    void redo ();	
+	};
+
+    } // namespace ResourceOps
+} // namespace Guikachu
 
 #endif /* !GUIKACHU_RESOURCE_MANAGER_OPS_H */
