@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.44 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.45 2003/01/31 20:58:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 #include "config.h"
 
 #include "mainwin.h"
+#include "session.h"
 #include "resource-util.h"
 
 #include "dialog-res.h"
@@ -292,8 +293,9 @@ void ResourceManager::set_dirty ()
 
 void ResourceManager::clear_dirty ()
 {
-    while (Gtk::Main::events_pending ())
-	Gtk::Main::iteration ();
+    if (Guikachu::Main::initialized ())
+	while (Gtk::Main::events_pending ())
+	    Gtk::Main::iteration ();
     
     modification_time = 0;
     dirty = false;
