@@ -1,4 +1,4 @@
-//$Id: resource-manager.h,v 1.26 2002/10/23 16:03:34 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.27 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -67,7 +67,8 @@ namespace Guikachu
 	~ResourceManager ();
 	
 	Resource* create_resource (Resources::Type type,
-				   std::string     id = "");
+				   std::string     id = "",
+				   bool            try_alternate_names = false);
 	void remove_resource (Resource *resource);
 	bool rename_resource (const std::string &old_id,
 			      const std::string &new_id);
