@@ -1,4 +1,4 @@
-//$Id: resource-ref.cc,v 1.6 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: resource-ref.cc,v 1.7 2002/06/02 13:53:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,19 +22,19 @@ using namespace Guikachu::Properties;
 using std::string;
 
 ResourceRef::ResourceRef (notify_signal_t &notify_signal,
+			  ResourceManager *manager_,
 			  const string    &value_):
-    Property<string> (notify_signal, value_)
+    Property<string> (notify_signal, value_),
+    manager (manager_)
 {
-    current_resource = ResourceManager::get_resource (value);
+    current_resource = manager->get_resource (value);
 
     if (current_resource)
 	current_resource_changed = current_resource->changed.connect (
 	    SigC::slot (this, &ResourceRef::resource_changed_cb));
 
-    ResourceManager::resource_created.connect (
-	SigC::slot (this, &ResourceRef::resource_created_cb));
-    ResourceManager::resource_removed.connect (
-	SigC::slot (this, &ResourceRef::resource_removed_cb));
+    manager->resource_created.connect (SigC::slot (this, &ResourceRef::resource_created_cb));
+    manager->resource_removed.connect (SigC::slot (this, &ResourceRef::resource_removed_cb));
 }
 
 void ResourceRef::set_val (const string &value_)
@@ -42,7 +42,7 @@ void ResourceRef::set_val (const string &value_)
     if (value_ == "")
 	Property<string>::set_val ("");
     
-    Resource *new_resource = ResourceManager::get_resource (value_);
+    Resource *new_resource = manager->get_resource (value_);
 
     if (new_resource != current_resource)
     {
