@@ -1,4 +1,4 @@
-//$Id: storage-node.h,v 1.13 2002/06/19 16:08:06 cactus Exp $ -*- c++ -*-
+//$Id: storage-node.h,v 1.15 2002/08/13 23:55:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,7 +20,7 @@
 #define GUIKACHU_STORAGE_NODE_H
 
 #include <string>
-#include <gnome-xml/tree.h>
+#include <libxml/tree.h>
 #include "property.h"
 
 namespace Guikachu
@@ -29,15 +29,18 @@ namespace Guikachu
     
     class StorageNode
     {
+	bool        free_node;
 	xmlNodePtr  node_ptr;
 	Storage    *parent_doc;
 
 	friend class Storage;
 
-	StorageNode ();
 	StorageNode (xmlNodePtr node, Storage *parent_doc);
 
     public:
+	StorageNode ();
+	~StorageNode ();
+	
 	std::string name () const;
 	inline xmlNodePtr c_node () const { return node_ptr; };
 	
