@@ -1,4 +1,4 @@
-//$Id: storage.h,v 1.8 2002/08/15 23:09:59 cactus Exp $ -*- c++ -*-
+//$Id: storage.h,v 1.10 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,12 +33,17 @@ namespace Guikachu
 	
     public:
 	Storage ();
+	Storage (xmlDocPtr doc);
 	~Storage ();
 
+	Storage (const Storage &other);
+	Storage & operator= (const Storage &other);
+	
 	GnomeVFSResult load     (const std::string &filename);
 
 	GnomeVFSResult load_uri (const std::string &uri);
 	GnomeVFSResult save_uri (const std::string &uri) const;
+	void           save_buffer (xmlChar *&buffer, int &buffer_size) const;
 	
 	StorageNode get_root    ();
 	void        set_root    (StorageNode &root);
