@@ -1,4 +1,4 @@
-//$Id: string-res.h,v 1.15 2002/08/01 18:06:01 cactus Exp $ -*- c++ -*-
+//$Id: string-res.h,v 1.16 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,7 +42,7 @@ namespace Guikachu
 	{
 	    GUI::StringWindow *gui;
 	public:
-	    String (ResourceManager *owner, const std::string &id);
+	    String (ResourceManager *manager, const std::string &id);
 	    ~String ();
 
 	    Type get_type () const { return RESOURCE_STRING; };
