@@ -1,4 +1,4 @@
-//$Id: stringlist-res.h,v 1.6 2002/08/01 18:06:01 cactus Exp $ -*- c++ -*-
+//$Id: stringlist-res.h,v 1.7 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -43,7 +43,7 @@ namespace Guikachu
 	{
 	    GUI::StringListWindow *gui;
 	public:
-	    StringList (ResourceManager *owner, const std::string &id);
+	    StringList (ResourceManager *manager, const std::string &id);
 	    ~StringList ();
 
 	    Type get_type () const { return RESOURCE_STRINGLIST; };
