@@ -1,4 +1,4 @@
-//$Id: treeitem.cc,v 1.15 2002/10/27 22:17:14 cactus Exp $ -*- c++ -*-
+//$Id: treeitem.cc,v 1.16 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,7 @@
 #include <libgnome/libgnome.h>
 
 #include "resource-manager-ops.h"
+#include "edit-cut-and-paste.h"
 
 #include <gnome--/app-helper.h>
 #include <libgnomeui/gnome-stock.h>
@@ -40,12 +41,17 @@ GUI::TreeItem::TreeItem (Resource *res_):
     res->changed.connect (slot (this, &GUI::TreeItem::resource_changed_cb));
     
     std::list <UI::Info> popup_menu_list;
-    popup_menu_list.push_back (
-	UI::Item (UI::Icon (GNOME_STOCK_MENU_PROP),
-		  _("_Edit"), SigC::slot (this, &GUI::TreeItem::menu_edit_cb)));
-    popup_menu_list.push_back (
-	UI::Item (UI::Icon (GNOME_STOCK_MENU_TRASH),
-		  _("_Remove"), SigC::slot (this, &GUI::TreeItem::menu_remove_cb)));
+    popup_menu_list.push_back (UI::Item (
+	UI::Icon (GNOME_STOCK_MENU_PROP), _("_Edit"),
+	SigC::slot (this, &GUI::TreeItem::menu_edit_cb)));
+    popup_menu_list.push_back (UI::Separator ());
+    popup_menu_list.push_back (MenuItems::Cut (SigC::slot (this, &GUI::TreeItem::menu_cut_cb)));
+    popup_menu_list.push_back (MenuItems::Copy (SigC::slot (this, &GUI::TreeItem::menu_copy_cb)));
+    popup_menu_list.push_back (UI::Separator ());
+    popup_menu_list.push_back (UI::Item (
+	UI::Icon (GNOME_STOCK_MENU_TRASH), _("_Remove"),
+	SigC::slot (this, &GUI::TreeItem::menu_remove_cb)));
+
     UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
 }
 
@@ -101,3 +107,14 @@ void GUI::TreeItem::menu_edit_cb ()
     res->show_ui ();
 }
 
+void GUI::TreeItem::menu_cut_cb ()
+{
+    menu_copy_cb ();
+    menu_remove_cb ();
+}
+
+void GUI::TreeItem::menu_copy_cb ()
+{
+    Edit::copy_resource (res);
+}
+
