@@ -1,4 +1,4 @@
-//$Id: entry.cc,v 1.8 2002/06/29 21:10:11 cactus Exp $ -*- c++ -*-
+//$Id: entry.cc,v 1.11 2002/10/12 21:31:08 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,10 +23,12 @@
 
 using namespace Guikachu::GUI::PropertyEditors;
 
-Entry::Entry (bool                   live_update,
-	      Property<std::string> &property_):
+Entry::Entry (bool          live_update,
+	      property_t   &property_,
+	      op_factory_t *op_factory_):
     PropertyEditor (this),
     property (property_),
+    op_factory (op_factory_),
     update_block (false),
     cursor_pos (-1)
 {
@@ -51,10 +53,16 @@ void Entry::changed_cb ()
         return;
 
     update_block = true;
-    
-    cursor_pos = get_position ();
-    property = get_text ();
 
+    const std::string new_val = get_text ();
+
+    if (property != new_val)
+    {
+	cursor_pos = get_position ();
+	
+	op_factory->push_change (new_val);
+    }
+    
     update_block = false;
     
     update ();
