@@ -1,4 +1,4 @@
-//$Id: font-combo.cc,v 1.2 2002/01/09 17:26:45 cactus Exp $ -*- c++ -*-
+//$Id: font-combo.cc,v 1.3 2002/10/26 11:06:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,9 +25,11 @@
 
 using namespace Guikachu::GUI::PropertyEditors;
 
-FontCombo::FontCombo (Property<int> &property_):
+FontCombo::FontCombo (property_t   &property_,
+		      op_factory_t *op_factory_):
     PropertyEditor (this),
     property (property_),
+    op_factory (op_factory_),
     update_block (false)
 {
     Gtk::Menu *menu_items = new Gtk::Menu;
@@ -72,5 +74,5 @@ void FontCombo::menu_cb (int font_num)
     if (update_block)
 	return;
 
-    property = font_num;
+    op_factory->push_change (font_num);
 }
