@@ -1,4 +1,4 @@
-//$Id: pos-entry.cc,v 1.7 2002/06/02 13:53:43 cactus Exp $ -*- c++ -*-
+//$Id: pos-entry.cc,v 1.8 2002/10/26 15:55:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,8 +25,9 @@
 using namespace Guikachu::GUI::PropertyEditors;
 
 XPosEntry::XPosEntry (ResourceManager *manager,
-		      Property<int>   &property):
-    NumEntry (0, (manager->get_target ()->screen_width - 1), property),
+		      property_t      &property,
+		      op_factory_t    *op_factory) :
+    NumEntry (0, (manager->get_target ()->screen_width - 1), property, op_factory),
     target (manager->get_target ())
 {
     target->changed.connect (SigC::slot (this, &XPosEntry::target_changed_cb));
@@ -38,8 +39,9 @@ void XPosEntry::target_changed_cb ()
 }
 
 YPosEntry::YPosEntry (ResourceManager *manager,
-		      Property<int>   &property):
-    NumEntry (0, (manager->get_target ()->screen_height - 1), property),
+		      property_t      &property,
+		      op_factory_t    *op_factory) :
+    NumEntry (0, (manager->get_target ()->screen_height - 1), property, op_factory),
     target (manager->get_target ())
 {
     target->changed.connect (SigC::slot (this, &YPosEntry::target_changed_cb));
