@@ -1,4 +1,4 @@
-//$Id: size-entry.cc,v 1.7 2002/06/02 13:53:43 cactus Exp $ -*- c++ -*-
+//$Id: size-entry.cc,v 1.8 2002/10/26 15:55:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,8 +24,9 @@
 using namespace Guikachu::GUI::PropertyEditors;
 
 WidthEntry::WidthEntry (ResourceManager *manager,
-			Property<int>   &property):
-    NumEntry (1, manager->get_target ()->screen_width, property),
+			property_t      &property,
+			op_factory_t    *op_factory) :
+    NumEntry (1, manager->get_target ()->screen_width, property, op_factory),
     target (manager->get_target ())
 {
     target->changed.connect (SigC::slot (this, &WidthEntry::target_changed_cb));
@@ -37,8 +38,9 @@ void WidthEntry::target_changed_cb ()
 }
 
 HeightEntry::HeightEntry (ResourceManager *manager,
-			  Property<int>   &property):
-    NumEntry (1, manager->get_target ()->screen_height, property),
+			  property_t      &property,
+			  op_factory_t    *op_factory) :
+    NumEntry (1, manager->get_target ()->screen_height, property, op_factory),
     target (manager->get_target ())
 {
     target->changed.connect (SigC::slot (this, &HeightEntry::target_changed_cb));
