@@ -1,4 +1,4 @@
-//$Id: widget-combo.cc,v 1.11 2002/01/01 21:23:43 cactus Exp $ -*- c++ -*-
+//$Id: widget-combo.cc,v 1.12 2002/09/01 22:45:07 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,14 +23,16 @@
 
 using namespace Guikachu::GUI::PropertyEditors;
 
-WidgetCombo::WidgetCombo (Resources::Form       *form_,
-			  Widgets::Type          type_,
-			  Properties::WidgetRef &property_):
+WidgetCombo::WidgetCombo (Resources::Form *form_,
+			  Widgets::Type    type_,
+			  property_t      &property_,
+			  op_factory_t    *op_factory_):
     Gtk::HBox (false, 5),
     form (form_),
     button_edit (_("Edit...")),
     type (type_),
-    property (property_)
+    property (property_),
+    op_factory (op_factory_)
 {
     combo.set_value_in_list (true, true);
     combo.set_use_arrows (true);
@@ -102,6 +104,7 @@ void WidgetCombo::update ()
     update_block = true;
     
     combo.get_entry ()->set_text (property);
+    button_edit.set_sensitive (property != "");
     
     update_block = false;
 }
@@ -122,15 +125,15 @@ void WidgetCombo::edit_cb ()
 
 void WidgetCombo::entry_cb ()
 {
-    if (!update_block)
-    {
-	property = combo.get_entry ()->get_text ();
-    }
+    if (update_block)
+	return;
+
+    const std::string new_val = combo.get_entry ()->get_text ();
+    if (property == new_val)
+	return;
     
-    if (property != "")
-	button_edit.set_sensitive (true);
-    else
-	button_edit.set_sensitive (false);
+    op_factory->push_change (new_val);
+    property = new_val;
 }
 
 void WidgetCombo::widget_changed_cb (Guikachu::Widget *widget)
